==> haskell-hasql-1.4-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.4
id: hasql-1.4-DLni2YYahepB1Z0PFWP8Z7
key: hasql-1.4-DLni2YYahepB1Z0PFWP8Z7
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver with a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
abi: 97e87a5391123e50683412abf5f0255f
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement
hidden-modules: Hasql.Private.Prelude Hasql.Private.Errors
                Hasql.Private.PTI Hasql.Private.IO Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders Hasql.Private.Decoders.Array
                Hasql.Private.Decoders.Composite Hasql.Private.Decoders.Value
                Hasql.Private.Decoders.Row Hasql.Private.Decoders.Result
                Hasql.Private.Decoders.Results Hasql.Private.Encoders
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-1.4
hs-libraries: HShasql-1.4-DLni2YYahepB1Z0PFWP8Z7
depends:
    attoparsec-0.13.2.2-6hbeq4AVpu4BObfg0Ve4St base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.3-8DDe5qfC8jB5aGdDVaqq8t
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    dlist-0.8.0.7-HVlmecz9w4Y387IWIU1Dvx
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hashtables-1.2.3.4-27kFAI3EbWD5WuakaktwlQ
    loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7 mtl-2.2.2
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    postgresql-binary-0.12.1.3-FrOeFjxgJGb7htHMwYLFBo
    postgresql-libpq-0.9.4.2-HyacS45qPUc33pszxfYdpM
    profunctors-5.4-3h6ix2rxY1UvIjMIvDbb3 text-1.2.3.1
    text-builder-0.6.5.1-CjQbyDgWDJR3Dwt69b786H transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.4-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.4
id: hasql-1.4-DaHRRaIFSmaB9t6T9J2PUN
key: hasql-1.4-DaHRRaIFSmaB9t6T9J2PUN
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver with a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API comes free from all kinds of exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
category: Hasql, Database, PostgreSQL
abi: f250807537852c89c934bdeffd9c22aa
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement
hidden-modules: Hasql.Private.Prelude Hasql.Private.Errors
                Hasql.Private.PTI Hasql.Private.IO Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders Hasql.Private.Decoders.Array
                Hasql.Private.Decoders.Composite Hasql.Private.Decoders.Value
                Hasql.Private.Decoders.Row Hasql.Private.Decoders.Result
                Hasql.Private.Decoders.Results Hasql.Private.Encoders
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-1.4
hs-libraries: HShasql-1.4-DaHRRaIFSmaB9t6T9J2PUN
depends:
    attoparsec-0.13.2.3-C8ToaI6DNPR6ujzYigEqDi base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.3-Gv1SDVCnWsoFfvCp1QVrp5
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    contravariant-extras-0.3.4-35VdvcJZeo7BMor95g7S78
    dlist-0.8.0.7-4YlHXedX3EE3dGnI3L89Bl
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hashtables-1.2.3.4-27kFAI3EbWD5WuakaktwlQ
    loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7 mtl-2.2.2
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    postgresql-binary-0.12.1.3-6h8SlpDG0i0CKeHCNTo675
    postgresql-libpq-0.9.4.2-HyacS45qPUc33pszxfYdpM
    profunctors-5.5-C3RSa0newLDGrqKqFpjE7c text-1.2.3.1
    text-builder-0.6.5.1-Ivq2LKcEvM4GwOH7fVstA9 transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
